/*-
 * Copyright (c) 2011 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Matt Thomas of 3am Software Foundry.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _EVBMIPS_UBOOT_H_
#define _EVBMIPS_UBOOT_H_

struct uboot_global_data {
        struct uboot_board_data *gd_bd;
        uint32_t gd_flags;
        uint32_t gd_baudrate;
        uint32_t gd_have_console;
        uint32_t gd_memsize;
        uint32_t gd_reloc_off;
        uint32_t gd_env_addr;
        uint32_t gd_env_valid;
        void **gd_jump_table;
};

struct uboot_board_data {
	uint32_t bd_baudrate;
	uint32_t bd_ipaddr;
	uint8_t bd_etheraddr[6];
	uint32_t bd_arch_number;
	uint32_t bd_boot_params;
	uint32_t bd_memstart;
	uint32_t bd_memsize;
	uint32_t bd_flashstart;
	uint32_t bd_flashsize;
	uint32_t bd_flashoffset;
};

#endif /* _EVBMIPS_UBOOT_H_ */
