/* $NetBSD: types.h,v 1.10 2017/01/26 15:55:10 christos Exp $ */

#ifndef _SBMIPS_TYPES_H_
#define	_SBMIPS_TYPES_H_

#define	_MIPS_PADDR_T_64BIT

#include <mips/types.h>

#define	__HAVE_NEW_STYLE_BUS_H
#define	__HAVE_COMPAT_NETBSD32

#endif
