/*	$NetBSD: algor_p6032reg.h,v 1.2 2008/04/28 20:23:10 martin Exp $	*/

/*-
 * Copyright (c) 2001 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Jason R. Thorpe.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

/*
 * Memory map and register definitions for the Algorithmics P-6032.
 */

#include <mips/bonito/bonitoreg.h>

#define	P6032_HDSP2532_BASE	(BONITO_DEV_BASE + 0x40000)

/*
 * The Algorithmics PMON initializes two DMA windows:
 *
 *	PCI 0080.0000 -> Phys 0000.0000 (8MB)
 *
 *	PCI 8000.0000 -> Phys 0000.0000 (256MB)
 */
#define	P6032_DMA_ISA_PCIBASE	0x00800000UL
#define	P6032_DMA_ISA_PHYSBASE	0x00000000UL
#define	P6032_DMA_ISA_SIZE	(8 * 1024 * 1024)

#define	P6032_DMA_PCI_PCIBASE	0x80000000UL
#define	P6032_DMA_PCI_PHYSBASE	0x00000000UL
#define	P6032_DMA_PCI_SIZE	(256 * 1024 * 1024)
