/*	$NetBSD: sa11x1_pcicvar.h,v 1.3 2008/04/28 20:23:14 martin Exp $ */

/*-
 * Copyright (c) 2001 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by IWAMOTO Toshihiro.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SA11X1_PCICVAR_H_
#define _SA11X1_PCICVAR_H_

struct sacpcic_softc {
	struct sapcic_softc sc_pc;
	bus_space_handle_t sc_ioh;
	
	struct sapcic_socket sc_socket[2];
};

void	sacpcic_attach_common(struct sacc_softc *, struct sacpcic_softc *,
	    void *, void (*)(struct sapcic_socket *));

int	sacpcic_read(struct sapcic_socket *, int);
void	sacpcic_write(struct sapcic_socket *, int, int);
void	sacpcic_set_power(struct sapcic_socket *, int);
void	sacpcic_clear_intr(int);
void	*sacpcic_intr_establish(struct sapcic_socket *, int,
				       int (*)(void *), void *);
void	sacpcic_intr_disestablish(struct sapcic_socket *, void *);

#endif /* _SA11X1_PCICVAR_H_ */
